# Phase 0. Foundation: Transformation Strategy and Setup
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/erp-transformation-foundation#overview)
  * [The Contribution of Enterprise Architects to Phase 0](https://help.sap.com/docs/leanix/ea/erp-transformation-foundation#the-contribution-of-enterprise-architects-to-phase-0)
  * [Define the Role of EA for the Subsequent Phases of the ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation-foundation#define-the-role-of-ea-for-the-subsequent-phases-of-the-erp-transformation)


Define goals and strategy for transformation, laying the foundation for well-informed migration decisions and budget planning. Clearly outline the role of Enterprise Architect in the process.
